
#include "Feu.h"
#include <Arduino.h>

//Constructeur permettant d'initialiser un Feu  partir de trois Led - state=0(vert), durations=1000(ms pour les trois)
Feu::Feu(Led vert, Led orange, Led rouge) {
    leds[0]=vert; leds[1]=orange ; leds[2]= rouge;
    state=0;        // vert
    mode=0;         // manuel
    for (int i=0 ; i<3 ; i++)durations[i]=1000;     // 1 seconde  tout le monde
}

//setter: permet de modifier l'tat (0=vert, 1=orange, 2=rouge)
void Feu::set_state(int value) {
    if (value>=0 && value<=2) {     // un tat valide
        state = value;
        for (int i=0 ; i<3 ; i++)       // on met les leds dans cet tat
            if (i==state)leds[i].lightOn();
                else leds[i].lightOff();
    }
}

//setter: permet de modifier le mode de fonctionnement courant (0=manuel, 1=automatique, 2=orange clignotant)
void Feu::set_mode(int value) {
    if (value>=0 && value <=2)  mode = value;
    if (mode == MODE_ORANGE_CLI) set_state(ORANGE);
}

//setter: permet de rgler la dure d'une couleur
void Feu::set_duration(int number, int duration){
    if (number>=0 && number<=2)durations[number] = duration;
}

//setter: permet de rgler la dure des trois couleurs vert, orange, rouge
void Feu::set_duration(int vert, int orange, int rouge){
    durations[VERT]=vert;
    durations[ORANGE]=orange;
    durations[ROUGE]=rouge;
}

//Cette mthode permet de synchroniser le feu avec la boucle principal. Pour que le Feu fonctionne automatiquement, il faut l'appeler dans la boucle principale du programme. La fonction sync n'est pas bloquante.
void Feu::sync() {
    static long lastMillis=0;
    long now = millis();
    switch(mode){
    case 0:     // manuel on ne fait rien
    case 1:     // automatique on change d'tat
        if (now-lastMillis>=durations[state]){      // c'est fini pour cet tat
            set_state((state+1)%3);                 // on passe au suivant
            lastMillis = now;
        }
        break;
    case 2:     // orange clignotant
        if (now-lastMillis>=durations[1]){
                leds[1].invert();     // l'orange clignote
                lastMillis = now;
        }
        break;
    }
}

