#include <Arduino.h>
#include "Led.h"

void Led::set_pin(int value) {
  if (validPin(value)){         // si le n de pin n'est pas valid, on ne fait rien
	  pinMode(value, OUTPUT);
	  pin = value;
  }
}

void Led::set_oneLogic(bool value) {
  oneLogic = value;
}

//constructeur par dfaut: pin = -1 (non dfinie, state=false, oneLogic=true
Led::Led(){
  pin=-1;           // -1 = pin invalid a priorin
  state=0;
  oneLogic=true;    // logique "1" par dfaut
}

//constructeur:  pin =numro de la pin Arduino, oneLogic= type de logique de commande (high ou low)
Led::Led(int pin, bool oneLogic){
  set_pin(pin);
  state=0;          // eteint par dfaut
  this->oneLogic=oneLogic;
}

//Cette mthode allume la led
void Led::lightOn() {
  if (pin==-1) return;      // pin invalide, on ne fait rien
  digitalWrite(pin, (oneLogic ? HIGH : LOW));
  state=true;
}

//Cette mthode teint la led
void Led::lightOff() {
  if (pin==-1) return;      // pin invalide, on ne fait rien
  digitalWrite(pin, (oneLogic ? LOW : HIGH));
  state=false;
}

//Cette mthode inverse l'tat de la led
void Led::invert() {
     if (state)lightOff(); else lightOn();
}

//Cette mthode allume la led pendant ms millisecondes puis l'teint
void Led::flash(int ms) {
     if (state) return;     // dj allum
     lightOn();
     delay(ms);
     lightOff();
}

//cette mthode vrifie si le n de pin est valide (en fonction du type de carte: nano, uno, .etc.)
// pour en changer, il faut modifier la ligne: #define ARDUINO_VALID_PIN dans le header de la classe
#define ARDUINO_VALID_PIN pin>=2 && pin<=12         // nano

bool Led::validPin(int pin) {
    return ARDUINO_VALID_PIN;
}

